Getting Started
===============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started/whats_in_the_framework
   getting_started/agents_and_the_state_table
   getting_started/what_is_a_components
   getting_started/simulation_lifecycle
